# Angular 数字缩写管道 (TokPipe)

## 1. 使用管道

### 基本使用

```html
<!-- 在模板中使用 -->
<p>{{ 1234 | tok }}</p>          <!-- 输出: 1.2k -->
<p>{{ 12345678 | tok }}</p>      <!-- 输出: 12.3m -->
<p>{{ 1234 | tok:{system: 'eastern'} }}</p>  <!-- 输出: 0.1万 -->
```

### 带参数使用

```html
<p>{{ 1500 | tok:{decimal: 0} }}</p>         <!-- 输出: 2k -->
<p>{{ 1500000 | tok:{system: 'eastern'} }}</p>  <!-- 输出: 150万 -->
<p>{{ 1500000 | tok:{decimal: 2, suffix: '元'} }}</p>  <!-- 输出: 1.50m元 -->
```

### 在组件类中使用

```typescript
import { TokPipe } from './tok.pipe';

@Component({
  standalone: true,
  imports: [TokPipe],
  // ...
})
export class MyComponent {
  private tokPipe = new TokPipe();
  
  formatNumber(num: number): string {
    return this.tokPipe.transform(num, { system: 'eastern' });
  }
}
```

## 2. 注册为独立管道

由于我们设置了 `standalone: true`，这个管道可以直接在任何独立组件中导入使用：

```typescript
import { TokPipe } from './tok.pipe';

@Component({
  standalone: true,
  imports: [TokPipe],
  template: `
    <p>{{ largeNumber | tok }}</p>
  `
})
export class MyStandaloneComponent {
  largeNumber = 1234567;
}
```

## 3. 可选：添加到共享模块

如果你想在非独立组件中使用，可以将其添加到共享模块：

```typescript
import { NgModule } from '@angular/core';
import { TokPipe } from './tok.pipe';

@NgModule({
  declarations: [TokPipe],
  exports: [TokPipe]
})
export class SharedModule {}
```

然后在需要的模块中导入 `SharedModule` 即可。

## 特点

1. 支持两种数字缩写系统：西方(k/m/b)和东方(万/亿)
2. 可配置小数位数
3. 可添加后缀
4. 自动处理负数和字符串输入
5. 作为独立管道，可以直接导入使用
6. 移除不必要的.0后缀

你可以根据需要进一步扩展或修改这个管道。