import { Pipe, PipeTransform } from '@angular/core';

@Pipe({
  name: 'tok',
  standalone: true  // 设置为独立管道，可以直接在组件中导入使用
})
export class TokPipe implements PipeTransform {
  transform(value: number | string, args?: {
    decimal?: number,
    system?: 'western' | 'eastern',
    suffix?: string
  }): string {
    // 默认参数
    const options = {
      decimal: 1,
      system: 'western', // 'western' (k,m,b) 或 'eastern' (万,亿)
      suffix: '',
      ...args
    };

    // 转换输入为数字
    let num = typeof value === 'string' ? parseFloat(value) : value;
    if (isNaN(num)) return String(value);

    // 处理负数
    const isNegative = num < 0;
    num = Math.abs(num);

    let result: string;

    if (options.system === 'eastern') {
      // 中文单位系统 (万, 亿)
      if (num >= 100000000) {
        result = (num / 100000000).toFixed(options.decimal) + '亿';
      } else if (num >= 10000) {
        result = (num / 10000).toFixed(options.decimal) + '万';
      } else {
        result = num.toString();
      }
    } else {
      // 西方单位系统 (k, m, b)
      if (num >= 1000000000) {
        result = (num / 1000000000).toFixed(options.decimal) + 'b';
      } else if (num >= 1000000) {
        result = (num / 1000000).toFixed(options.decimal) + 'm';
      } else if (num >= 1000) {
        result = (num / 1000).toFixed(options.decimal) + 'k';
      } else {
        result = num.toString();
      }
    }

    // 移除不必要的 .0
    if (options.decimal > 0) {
      result = result.replace(/\.0+$/, '');
    }

    // 添加后缀和负号
    return (isNegative ? '-' : '') + result + options.suffix;
  }
}