// src/app/shared/directives/echarts.directive.ts
import { Directive, ElementRef, Input, OnChanges, SimpleChanges } from '@angular/core';
import * as echarts from 'echarts';

@Directive({
  selector: '[appEchart]',
  standalone: true
})
export class EchartDirective implements OnChanges {
  @Input() echartOptions: any;
  private chart: any;

  constructor(private el: ElementRef) {}

  ngOnChanges(changes: SimpleChanges) {
    if (changes['echartOptions']) {
      this.renderChart();
    }
  }

  private renderChart() {
    if (!this.chart) {
      this.chart = echarts.init(this.el.nativeElement);
    }

    if (this.echartOptions) {
      this.chart.setOption(this.echartOptions);
    }
  }

  ngOnDestroy() {
    if (this.chart) {
      this.chart.dispose();
    }
  }
}
